/*
  Copyright 2021 Kakao Corp.

  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
 */
package com.kakao.sdk.partner.friend.model

import android.os.Parcelable
import com.google.gson.annotations.SerializedName
import com.kakao.sdk.partner.friend.Constants
import kotlinx.android.parcel.Parcelize

/**
 * TODO: comment
 */

@Parcelize
class PickerRequestParams(
    val title: String? = null,
    val pickerFriendOrder: PickerFriendOrder? = null,
    val pickerFriendType: PickerFriendType? = Constants.DEFAULT_PICKER_FRIEND_TYPE,
    val pickerFriendFilter: PickerFriendFilter? = Constants.DEFAULT_PICKER_FRIEND_FILTER,
    val viewAppearance: ViewAppearance? = Constants.DEFAULT_PICKER_VIEW_APPEARANCE,
    val countryCodes: List<String>? = null,
    val usingOsFilter: OsFilter? = Constants.DEFAULT_OS_FILTER,
    val orientation: PickerOrientation? = Constants.DEFAULT_PICKER_ORIENTATION,
    val enableSearch: Boolean? = Constants.DEFAULT_ENABLE_SEARCH,
    val searchPlaceHolder: String? = null,
    val enableIndex: Boolean? = Constants.DEFAULT_ENABLE_INDEX,
    val showMyProfile: Boolean? = Constants.DEFAULT_SHOW_MY_PROFILE,
    val showFavorite: Boolean? = Constants.DEFAULT_SHOW_FAVORITE,
    val disableSelectReasons: DisableSelectionReason? = null,
    val maxPickableCount: Int? = Constants.DEFAULT_MAX_PICKABLE_COUNT,
    val minPickableCount: Int? = Constants.DEFAULT_MIN_PICKABLE_COUNT,
    val showPickedFriend: Boolean? = Constants.DEFAULT_SHOW_PICKED_FRIENDS,
    val displayAllProfile: Boolean? = false
) : Parcelable

/**
 * 친구를 가져올 서비스 선택
 * TODO: comment
 */
enum class PickerFriendType {
    /**
     * 카카오톡 친구
     */
    @SerializedName("talk")
    KAKAO_TALK,

    /**
     * 카카오스토리 친구
     */
    @SerializedName("story")
    KAKAO_STORY,

    /**
     * 카카오톡과 카카오스토리 친구
     */
    @SerializedName("talkstory")
    KAKAO_TALK_AND_STORY
}

enum class PickerOrientation {
    PORTRAIT, LANDSCAPE, AUTO
}

/**
 * 친구 목록 필터링
 * TODO: comment
 */
enum class PickerFriendFilter {
    @SerializedName("none")
    NONE,

    @SerializedName("registered")
    REGISTERED,

    @SerializedName("invitable")
    INVITABLE
}

/**
 * TODO: comment
 */
enum class ViewAppearance {
    LIGHT, DARK, AUTO
}

/**
 * TODO: comment
 */
enum class OsFilter {
    ALL, ANDROID, IOS
}

/**
 * TODO: comment
 */
enum class DisableSelectionReason {
    MSG_BLOCKED
}

/**
 * 친구 목록 정렬 기준.
 * TODO: comment
 */
enum class PickerFriendOrder {
    /**
     * 나이 순 정렬
     */
    @SerializedName("age")
    AGE
}